# better python extensions

- ✅ 开箱即用的 python 扩展

## Installation

```ruby
pip install better-px

# or 
uv add better-px
```

## Usage

```python
from better_px import *

import px

# or if conflict
import better_px as px


def main():
    print(px.hello())
```

## References

- <https://github.com/better-py/py-pkg>
